==> json-joy-2.15.0.tgz: package/esm/reactive-rpc/server/uws/http/ndjson.js <==
import { Subject, of } from "rxjs";
import { takeUntil } from "rxjs/operators";
import { formatError } from "../../../common/rpc";
import { readBody } from "../util";
import { parsePayload, writeSseAndNdjsonHeaders } from "./util";
export const enableNdjsonPostRpcApi = (params) => {
    const { uws, route = '/ndjson/*', createContext, caller } = params;
    if (!route.endsWith('/*'))
        throw new Error('"route" must end with "/*".');
    uws.post(route, (res, req) => {
        const url = req.getUrl();
        const name = url.substr(route.length - 1);
        const origin = req.getHeader('origin');
        const ctx = createContext(req, res);
        const aborted$ = new Subject();
        res.onAborted(() => {
            res.aborted = true;
            aborted$.next(true);
        });
        readBody(res, (buffer) => {
            processNdjsonRequest(res, ctx, name, buffer, aborted$, origin, caller);
        });
    });
};
export const enableNdjsonGetRpcApi = (params) => {
    const { uws, route = '/ndjson/*', createContext, caller } = params;
    if (!route.endsWith('/*'))
        throw new Error('"route" must end with "/*".');
    uws.get(route, (res, req) => {
        const url = req.getUrl();
        const name = url.substr(route.length - 1);
        const origin = req.getHeader('origin');
        const ctx = createContext(req, res);
        const aborted$ = new Subject();
        const query = req.getQuery();
        const params = new URLSearchParams(query);
        const body = String(params.get('a') || 'null');
        res.onAborted(() => {
            res.aborted = true;
            aborted$.next(true);
        });
        processNdjsonRequest(res, ctx, name, body, aborted$, origin, caller);
    });
};
const sendNdjsonError = (res, error) => {
    if (res.aborted)
        return;
    res.aborted = true;
    const errorFormatted = formatError(error);
    res.end('[2,' + JSON.stringify(errorFormatted) + ']\n');
};
function processNdjsonRequest(res, ctx, name, body, aborted$, origin, caller) {
    let closed = false;
    try {
        const json = parsePayload(ctx, body);
        res.cork(() => {
            writeSseAndNdjsonHeaders(res, origin);
        });
        caller.call$(name, of(json), ctx)
            .pipe(takeUntil(aborted$))
            .subscribe({
            next: data => {
                if (closed)
                    return;
                if (res.aborted)
                    return;
                res.write('[1,' + JSON.stringify(data) + ']\n');
            },
            error: error => {
                if (closed)
                    return;
                closed = true;
                sendNdjsonError(res, error);
            },
            complete: () => {
                if (closed)
                    return;
                closed = true;
                if (!res.aborted)
                    res.end();
            },
        });
    }
    catch {
        if (closed)
            return;
        closed = true;
        const error = new Error('Could not parse payload');
        sendNdjsonError(res, error);
    }
}

==> json-joy-2.17.0.tgz: package/esm/reactive-rpc/server/uws/http/ndjson.js <==
import { Subject, of } from "rxjs";
import { takeUntil } from "rxjs/operators";
import { formatError } from "../../../common/rpc";
import { createConnectionContext } from "../context";
import { readBody } from "../util";
import { parsePayload, writeSseAndNdjsonHeaders } from "./util";
export const enableNdjsonPostRpcApi = (params) => {
    const { uws, route = '/ndjson/*', createContext = createConnectionContext, caller } = params;
    if (!route.endsWith('/*'))
        throw new Error('"route" must end with "/*".');
    uws.post(route, (res, req) => {
        const url = req.getUrl();
        const name = url.substr(route.length - 1);
        const origin = req.getHeader('origin');
        const ctx = createContext(req, res);
        const aborted$ = new Subject();
        res.onAborted(() => {
            res.aborted = true;
            aborted$.next(true);
        });
        readBody(res, (buffer) => {
            processNdjsonRequest(res, ctx, name, buffer, aborted$, origin, caller);
        });
    });
};
export const enableNdjsonGetRpcApi = (params) => {
    const { uws, route = '/ndjson/*', createContext = createConnectionContext, caller } = params;
    if (!route.endsWith('/*'))
        throw new Error('"route" must end with "/*".');
    uws.get(route, (res, req) => {
        const url = req.getUrl();
        const name = url.substr(route.length - 1);
        const origin = req.getHeader('origin');
        const ctx = createContext(req, res);
        const aborted$ = new Subject();
        const query = req.getQuery();
        const params = new URLSearchParams(query);
        const body = String(params.get('a') || 'null');
        res.onAborted(() => {
            res.aborted = true;
            aborted$.next(true);
        });
        processNdjsonRequest(res, ctx, name, body, aborted$, origin, caller);
    });
};
const sendNdjsonError = (res, error) => {
    if (res.aborted)
        return;
    res.aborted = true;
    const errorFormatted = formatError(error);
    res.end('[2,' + JSON.stringify(errorFormatted) + ']\n');
};
function processNdjsonRequest(res, ctx, name, body, aborted$, origin, caller) {
    let closed = false;
    try {
        const json = parsePayload(ctx, body);
        res.cork(() => {
            writeSseAndNdjsonHeaders(res, origin);
        });
        caller.call$(name, of(json), ctx)
            .pipe(takeUntil(aborted$))
            .subscribe({
            next: data => {
                if (closed)
                    return;
                if (res.aborted)
                    return;
                res.write('[1,' + JSON.stringify(data) + ']\n');
            },
            error: error => {
                if (closed)
                    return;
                closed = true;
                sendNdjsonError(res, error);
            },
            complete: () => {
                if (closed)
                    return;
                closed = true;
                if (!res.aborted)
                    res.end();
            },
        });
    }
    catch {
        if (closed)
            return;
        closed = true;
        const error = new Error('Could not parse payload');
        sendNdjsonError(res, error);
    }
}
